#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

/*-----------------------------------------------------------
 * Application specific definitions.
 *
 * These definitions should be adjusted for your particular hardware and
 * application requirements.
 *
 * THESE PARAMETERS ARE DESCRIBED WITHIN THE 'CONFIGURATION' SECTION OF THE
 * FreeRTOS API DOCUMENTATION AVAILABLE ON THE FreeRTOS.org WEB SITE.
 *----------------------------------------------------------*/

extern unsigned const configCPU_CLOCK_HZ;	// defined as memory locations to support
extern unsigned const configTICK_RATE_HZ;	// linking FreeRTOs as a library
// extern unsigned int configTOTAL_HEAP_SIZE;

#define configUSE_PREEMPTION		1
#define configUSE_IDLE_HOOK			1
#define configMAX_PRIORITIES		( ( unsigned portBASE_TYPE ) 20 )
#define configUSE_TICK_HOOK			1
#define configMINIMAL_STACK_SIZE	( ( unsigned short ) 128 )
// #define configTOTAL_HEAP_SIZE		( ( size_t ) ( 2560 ) )
#define configMAX_TASK_NAME_LEN		( 12 )
#define configUSE_TRACE_FACILITY	1
#define configUSE_16_BIT_TICKS		0
#define configIDLE_SHOULD_YIELD		0
#define configUSE_CO_ROUTINES 		0
#define configUSE_MUTEXES			1

#define configMAX_CO_ROUTINE_PRIORITIES ( 2 )

#define configUSE_COUNTING_SEMAPHORES 	1
#define configUSE_ALTERNATIVE_API 		0
#define configCHECK_FOR_STACK_OVERFLOW	1
#define configUSE_RECURSIVE_MUTEXES		1
#define configQUEUE_REGISTRY_SIZE		0
#define configGENERATE_RUN_TIME_STATS	0
#define configUSE_MALLOC_FAILED_HOOK	1

/* Set the following definitions to 1 to include the API function, or zero
to exclude the API function. */

#define INCLUDE_vTaskPrioritySet			1
#define INCLUDE_uxTaskPriorityGet			1
#define INCLUDE_vTaskDelete					1
#define INCLUDE_vTaskCleanUpResources		1
#define INCLUDE_vTaskSuspend				1
#define INCLUDE_vTaskDelayUntil				1
#define INCLUDE_vTaskDelay					1
#define INCLUDE_uxTaskGetStackHighWaterMark	0
#define INCLUDE_xTaskGetCurrentTaskHandle	1
#define configUSE_TIMERS					1
#define configTIMER_TASK_PRIORITY			tskIDLE_PRIORITY
#define configTIMER_QUEUE_LENGTH			10
#define configTIMER_TASK_STACK_DEPTH		configMINIMAL_STACK_SIZE

/* Cortex-M specific definitions. */
#ifdef __NVIC_PRIO_BITS
	/* __BVIC_PRIO_BITS will be specified when CMSIS is being used. */
	#define configPRIO_BITS       		__NVIC_PRIO_BITS
#else
	#define configPRIO_BITS       		4        /* 15 priority levels */
#endif

/* NVIC should be programmed to NVIC_PriorityGroup_4 -> 4 Preemption bits / 0 SubPrioBits */

/* The lowest interrupt priority that can be used in a call to a "set priority"
function. */
#define configLIBRARY_LOWEST_INTERRUPT_PRIORITY			0xf

/* The highest interrupt priority that can be used by any interrupt service
routine that makes calls to interrupt safe FreeRTOS API functions.  DO NOT CALL
INTERRUPT SAFE FREERTOS API FUNCTIONS FROM ANY INTERRUPT THAT HAS A HIGHER
PRIORITY THAN THIS! (higher priorities are lower numeric values. */
#define configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY	5

/* Interrupt priorities used by the kernel port layer itself.  These are generic
to all Cortex-M ports, and do not rely on any particular library functions. */
#define configKERNEL_INTERRUPT_PRIORITY 		( configLIBRARY_LOWEST_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )
#define configMAX_SYSCALL_INTERRUPT_PRIORITY 	( configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )

#if 0 // runtime instrumentation
#define ENTER_ISR 		(*(volatile int*)0x40011010=4)
#define LEAVE_ISR	  	// (*(volatile int*)0x40011014=4)
#define SWITCH_HOOK() 	// (*(volatile int*)0x40011010=4)
#define IDLE_HOOK()  	(*(volatile int*)0x40011014=4)
#else
#define ENTER_ISR
#define LEAVE_ISR
#endif

#if 1
#define configASSERT(x) if(!(x)){__asm volatile ( "bkpt 0" );}
#else
#define configASSERT(x)
#endif

#endif /* FREERTOS_CONFIG_H */

